@@ -499,7 +499,7 @@ class Poetry(PkgManager):
             "env.fetch",
         ],
     ) -> dict:
-        return {"env": ["PATH", "POETRY_VIRTUALENVS_PATH"]}
+        return {"env": ["PATH", "POETRY_VIRTUALENVS_PATH", "CC", "CXX"]}
 
     def parse_dep_spec(self, spec: Union[str, dict]) -> DepConstraint:
         if isinstance(spec, str):
